@@ -8,11 +8,13 @@ Usage::
     from mypy_boto3_networkmanager import (
         Client,
         DescribeGlobalNetworksPaginator,
+        GetConnectionsPaginator,
         GetCustomerGatewayAssociationsPaginator,
         GetDevicesPaginator,
         GetLinkAssociationsPaginator,
         GetLinksPaginator,
         GetSitesPaginator,
+        GetTransitGatewayConnectPeerAssociationsPaginator,
         GetTransitGatewayRegistrationsPaginator,
         NetworkManagerClient,
     )
@@ -23,22 +25,26 @@ Usage::
     session_client: NetworkManagerClient = session.client("networkmanager")
 
     describe_global_networks_paginator: DescribeGlobalNetworksPaginator = client.get_paginator("describe_global_networks")
+    get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
     get_customer_gateway_associations_paginator: GetCustomerGatewayAssociationsPaginator = client.get_paginator("get_customer_gateway_associations")
     get_devices_paginator: GetDevicesPaginator = client.get_paginator("get_devices")
     get_link_associations_paginator: GetLinkAssociationsPaginator = client.get_paginator("get_link_associations")
     get_links_paginator: GetLinksPaginator = client.get_paginator("get_links")
     get_sites_paginator: GetSitesPaginator = client.get_paginator("get_sites")
+    get_transit_gateway_connect_peer_associations_paginator: GetTransitGatewayConnectPeerAssociationsPaginator = client.get_paginator("get_transit_gateway_connect_peer_associations")
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
     ```
 """
 from mypy_boto3_networkmanager.client import NetworkManagerClient
 from mypy_boto3_networkmanager.paginator import (
     DescribeGlobalNetworksPaginator,
+    GetConnectionsPaginator,
     GetCustomerGatewayAssociationsPaginator,
     GetDevicesPaginator,
     GetLinkAssociationsPaginator,
     GetLinksPaginator,
     GetSitesPaginator,
+    GetTransitGatewayConnectPeerAssociationsPaginator,
     GetTransitGatewayRegistrationsPaginator,
 )
 
@@ -48,11 +54,13 @@ Client = NetworkManagerClient
 __all__ = (
     "Client",
     "DescribeGlobalNetworksPaginator",
+    "GetConnectionsPaginator",
     "GetCustomerGatewayAssociationsPaginator",
     "GetDevicesPaginator",
     "GetLinkAssociationsPaginator",
     "GetLinksPaginator",
     "GetSitesPaginator",
+    "GetTransitGatewayConnectPeerAssociationsPaginator",
     "GetTransitGatewayRegistrationsPaginator",
     "NetworkManagerClient",
 )
